@@ -18,6 +18,8 @@
 #include <QGeoPositionInfo>
 #include <QGeoSatelliteInfo>
 
+#include <QSqlDatabase>
+
 QTM_USE_NAMESPACE
 
 class ColumbusControllerPrivate;
@@ -35,6 +37,8 @@ public:
     ConfigManager*          config      () const;
     PluginManager*          plugins     () const;
     LoggingManager*         logger      () const;
+
+    QSqlDatabase            database    () const;
     ColumbusModel*          model       () const;
     ColumbusWaypointModel*  waypoints   () const;
 
